import { tap, expect } from '../../ts_tapbundle/index.js';

// First test sets some data and has tags
tap.tags('unit', 'context')
  .priority('high')
  .test('test with tags and context setting', async (toolsArg) => {
    // Set some data in context
    toolsArg.context.set('testData', { value: 42 });
    toolsArg.context.set('users', ['alice', 'bob']);
    
    expect(true).toBeTrue();
  });

// Second test reads the context data
tap.tags('unit', 'context')
  .test('test reading context', async (toolsArg) => {
    // Read data from context
    const testData = toolsArg.context.get('testData');
    const users = toolsArg.context.get('users');
    
    expect(testData).toEqual({ value: 42 });
    expect(users).toContain('alice');
    expect(users).toContain('bob');
  });

// Test without tags - should be skipped when filtering by tags
tap.test('test without tags', async (toolsArg) => {
  expect(true).toBeTrue();
});

// Test with different tags
tap.tags('integration')
  .priority('low')
  .test('integration test', async (toolsArg) => {
    expect(true).toBeTrue();
  });

// Test context cleanup
tap.tags('unit')
  .test('test context operations', async (toolsArg) => {
    // Set and delete
    toolsArg.context.set('temp', 'value');
    expect(toolsArg.context.get('temp')).toEqual('value');
    
    toolsArg.context.delete('temp');
    expect(toolsArg.context.get('temp')).toBeUndefined();
  });

tap.start();